@@ -1,5 +1,4 @@
 from django.core.exceptions import ImproperlyConfigured
-from django.views.decorators.csrf import csrf_protect
 from django.utils import timezone
 from django.conf import settings
 from django.shortcuts import render
@@ -41,7 +40,7 @@ class TokenViewSet(viewsets.ModelViewSet):
     def create(self, request, *args, **kwargs):
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)            
-        serializer.validated_data['owner'] = get_or_create_owner(request.META.get('HTTP_BCMR_AUTH'))
+        serializer.validated_data['owner'] = get_or_create_owner(request.META.get(settings.AUTH_HEADER))
         self.perform_create(serializer)
         headers = self.get_success_headers(serializer.data)
         return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)
@@ -72,7 +71,7 @@ class RegistryViewSet(viewsets.ModelViewSet):
     def create(self, request, *args, **kwargs):
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)            
-        serializer.validated_data['owner'] = get_or_create_owner(request.META.get('HTTP_BCMR_AUTH'))
+        serializer.validated_data['owner'] = get_or_create_owner(request.META.get(settings.AUTH_HEADER))
         self.perform_create(serializer)
         headers = self.get_success_headers(serializer.data)
         return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)
@@ -99,9 +98,8 @@ class RegistryViewSet(viewsets.ModelViewSet):
             return self.serializer_classes[self.action]
         return super().get_serializer_class()
 
-
-@csrf_protect
-def create_fungible_token(request):
+ 
+def create_token(request):
     submitted = False
     message = ''
     owner = ''
@@ -145,4 +143,4 @@ def create_fungible_token(request):
         'message': message,
         'owner': owner if type(owner) is str else owner.id
     }
-    return render(request, 'bcmr/add_token.html', context)
+    return render(request, 'bcmr/create_token.html', context)
